Oct2py is written and maintained by Steven Silvester and
various contributors:

Development Lead
````````````````

- Steven Silvester <steven.silvester@ieee.org>


Patches and Suggestions
```````````````````````

- Stefan van der Walt @stefanv
- Jens H Nielsen @jenshnielsen
- @idella
- @klonuo
- Juan Luis Cano Rodríguez @Juanlu001
- @bj0
- Thomas Grainger @graingert
- @jordigh
- @wannesm
- Konstantin Markov
- Benedikt Sauer @filmore

